==> igniteui-react-charts-18.2.0.tgz: package/esm2015/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let CategoryChartToolbarProvider = /*@__PURE__*/ (() => {
    class CategoryChartToolbarProvider extends DomainChartToolbarProvider {
        constructor() {
            super(...arguments);
            this.v = null;
        }
        d(a, b) {
            let c = a;
            switch (b.name) {
                case "ShowGridlines":
                    {
                        let d = b;
                        d.isChecked = c.acd != null;
                    }
                    break;
            }
        }
        r(a, b, c, d) {
            let e = a;
            switch (b) {
                case "XAxisMajorStroke":
                    this.e("ShowGridlines", 2, a.acd != null);
                    break;
            }
        }
        i(a, b) {
            let c = a;
            if (this.b(b, "ShowGridlines")) {
                if (c.acd == null) {
                    if (this.v != null) {
                        c.acd = this.v;
                    }
                    else {
                        c.acd = c.dataChart.xv;
                    }
                }
            }
            else {
                if (c.acd != null) {
                    this.v = c.acd;
                    c.acd = null;
                }
            }
        }
    }
    CategoryChartToolbarProvider.$t = /*@__PURE__*/ markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
})();

==> igniteui-react-charts-18.4.0.tgz: package/esm2015/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let CategoryChartToolbarProvider = /*@__PURE__*/ (() => {
    class CategoryChartToolbarProvider extends DomainChartToolbarProvider {
        constructor() {
            super(...arguments);
            this.y = null;
        }
        e(a, b) {
            let c = a;
            switch (b.name) {
                case "ShowGridlines":
                    {
                        let d = b;
                        d.isChecked = c.acg != null;
                    }
                    break;
            }
        }
        u(a, b, c, d) {
            let e = a;
            switch (b) {
                case "XAxisMajorStroke":
                    this.f("ShowGridlines", 2, a.acg != null);
                    break;
            }
        }
        k(a, b) {
            let c = a;
            if (this.c(b, "ShowGridlines")) {
                if (c.acg == null) {
                    if (this.y != null) {
                        c.acg = this.y;
                    }
                    else {
                        c.acg = c.dataChart.x5;
                    }
                }
            }
            else {
                if (c.acg != null) {
                    this.y = c.acg;
                    c.acg = null;
                }
            }
        }
    }
    CategoryChartToolbarProvider.$t = /*@__PURE__*/ markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
})();
